@@ -22,4 +22,4 @@ KateSQLOutputWidget::~KateSQLOutputWidget()
 {
 }
 
-// kate: space-indent on; indent-width 2; replace-tabs on;
+#include "moc_outputwidget.cpp"
