@@ -229,6 +229,7 @@ private:
     class QComboBox *const m_providerCombo;
     class QToolButton *const m_errFilterBtn;
     class QToolButton *const m_warnFilterBtn;
+    class KMessageWidget *const m_diagLimitReachedWarning;
 
     class ProviderListModel *m_providerModel;
 
@@ -248,4 +249,5 @@ private:
     QTimer *const m_filterChangedTimer;
     QTimer *const m_urlChangedTimer;
     std::unique_ptr<KateTextHintProvider> m_textHintProvider;
+    int m_diagnosticLimit = 0;
 };
